@@ -5,24 +5,25 @@ from __future__ import annotations
 from collections import deque
 from contextlib import asynccontextmanager
 from dataclasses import dataclass, field
-from datetime import datetime
 from typing import TYPE_CHECKING, Any, Literal, Self, overload
 from uuid import UUID, uuid4
 
 from llmling import BasePrompt, PromptMessage, StaticPrompt
 from llmling.config.models import BaseResource
 from psygnal import Signal
+from upathtools import read_path
 
 from llmling_agent.log import get_logger
 from llmling_agent.messaging.message_container import ChatMessageContainer
 from llmling_agent.messaging.messages import ChatMessage
-from llmling_agent.models.session import MemoryConfig, SessionQuery
-from llmling_agent.utils.async_read import read_path
 from llmling_agent.utils.count_tokens import count_tokens
+from llmling_agent.utils.now import get_now
+from llmling_agent_config.session import SessionQuery
 
 
 if TYPE_CHECKING:
     from collections.abc import AsyncIterator, Coroutine, Sequence
+    from datetime import datetime
     from types import TracebackType
 
     from llmling.config.models import Resource
@@ -31,6 +32,7 @@ if TYPE_CHECKING:
 
     from llmling_agent.agent.agent import Agent
     from llmling_agent.common_types import MessageRole, SessionIdType, StrPath
+    from llmling_agent_config.session import MemoryConfig
 
 logger = get_logger(__name__)
 
@@ -56,7 +58,7 @@ class ConversationManager:
         """Emitted when chat history is cleared."""
 
         session_id: str
-        timestamp: datetime = field(default_factory=datetime.now)
+        timestamp: datetime = field(default_factory=get_now)
 
     history_cleared = Signal(HistoryCleared)
 
@@ -152,6 +154,9 @@ class ConversationManager:
             case str():
                 query = SessionQuery(name=key)
                 return self._agent.context.storage.filter_messages_sync(query=query)
+            case _:
+                msg = f"Invalid key type: {type(key)}"
+                raise TypeError(msg)
 
     def __contains__(self, item: Any) -> bool:
         """Check if item is in history."""
@@ -428,6 +433,7 @@ class ConversationManager:
             name="user",
             model=self._agent.model_name,
             metadata=metadata,
+            conversation_id="context",  # TODO: should probably allow DB field to be NULL
         )
         self._pending_messages.append(chat_message)
         # Emit as user message - will trigger logging through existing flow
@@ -450,9 +456,9 @@ class ConversationManager:
         Raises:
             ValueError: If content cannot be loaded or converted
         """
-        from upath import UPath
+        from upathtools import to_upath
 
-        path_obj = UPath(path)
+        path_obj = to_upath(path)
         if convert_to_md:
             content = await self._agent.context.converter.convert_file(path)
             source = f"markdown:{path_obj.name}"
