@@ -1,3 +1,5 @@
+"""Base class for teams."""
+
 from __future__ import annotations
 
 from abc import abstractmethod
@@ -12,9 +14,10 @@ from llmling_agent.log import get_logger
 from llmling_agent.messaging.context import NodeContext
 from llmling_agent.messaging.messagenode import MessageNode
 from llmling_agent.models.manifest import AgentsManifest
-from llmling_agent.models.teams import TeamConfig
-from llmling_agent.talk.stats import AggregatedMessageStats, AggregatedTalkStats
+from llmling_agent.talk.stats import AggregatedMessageStats
+from llmling_agent.tools.base import Tool
 from llmling_agent.utils.inspection import has_return_type
+from llmling_agent_config.teams import TeamConfig
 
 
 if TYPE_CHECKING:
@@ -25,15 +28,14 @@ if TYPE_CHECKING:
     from psygnal.containers._evented_list import ListEvents
     from toprompt import AnyPromptType
 
-    from llmling_agent.agent import AnyAgent
+    from llmling_agent import AgentPool, AnyAgent, Team
     from llmling_agent.common_types import ModelType, ToolType
-    from llmling_agent.delegation.pool import AgentPool
-    from llmling_agent.delegation.team import Team
     from llmling_agent.delegation.teamrun import ExtendedTeamTalk, TeamRun
     from llmling_agent.messaging.messages import ChatMessage, TeamResponse
-    from llmling_agent.models.mcp_server import MCPServerConfig
-    from llmling_agent.models.providers import ProcessorCallback
-    from llmling_agent.models.session import SessionQuery
+    from llmling_agent.talk.stats import AggregatedTalkStats
+    from llmling_agent_config.mcp_server import MCPServerConfig
+    from llmling_agent_config.providers import ProcessorCallback
+    from llmling_agent_config.session import SessionQuery
     from llmling_agent_providers.base import AgentProvider
 
 logger = get_logger(__name__)
@@ -41,6 +43,8 @@ logger = get_logger(__name__)
 
 @dataclass(kw_only=True)
 class TeamContext[TDeps](NodeContext[TDeps]):
+    """Context for team nodes."""
+
     config: TeamConfig
     """Current team's specific configuration."""
 
@@ -61,7 +65,7 @@ class TeamContext[TDeps](NodeContext[TDeps]):
             mode: Execution mode (sequential or parallel)
             pool:(optional): Optional pool the agent is part of
         """
-        from llmling_agent.models import TeamConfig
+        from llmling_agent_config import TeamConfig
 
         cfg = TeamConfig(name=name, mode=mode, members=[])
         defn = AgentsManifest()
@@ -106,6 +110,32 @@ class BaseTeam[TDeps, TResult](MessageNode[TDeps, TResult]):
         self.num_picks = num_picks
         self.pick_prompt = pick_prompt
 
+    def to_tool(self, *, name: str | None = None, description: str | None = None) -> Tool:
+        """Create a tool from this agent.
+
+        Args:
+            name: Optional tool name override
+            description: Optional tool description override
+        """
+        tool_name = name or f"ask_{self.name}"
+
+        async def wrapped_tool(prompt: str) -> TResult:
+            result = await self.run(prompt)
+            return result.data
+
+        docstring = description or f"Get expert answer from node {self.name}"
+        if self.description:
+            docstring = f"{docstring}\n\n{self.description}"
+
+        wrapped_tool.__doc__ = docstring
+        wrapped_tool.__name__ = tool_name
+
+        return Tool.from_callable(
+            wrapped_tool,
+            name_override=tool_name,
+            description_override=docstring,
+        )
+
     async def pick_agents(self, task: str) -> Sequence[MessageNode[Any, Any]]:
         """Pick agents to run."""
         if self.picker:
