@@ -3,16 +3,11 @@
 from __future__ import annotations
 
 import asyncio
-from contextlib import (
-    AsyncExitStack,
-    asynccontextmanager,
-    suppress,
-)
+from contextlib import AsyncExitStack, asynccontextmanager, suppress
 import os
-from typing import TYPE_CHECKING, Any, Self, Unpack, cast, overload
+from typing import TYPE_CHECKING, Any, Self, TypeVar, Unpack, cast, overload
 
 from llmling import BaseRegistry, LLMLingError
-from typing_extensions import TypeVar
 
 from llmling_agent.agent import Agent, StructuredAgent
 from llmling_agent.common_types import NodeName
@@ -34,9 +29,7 @@ from llmling_agent_config.workers import AgentWorkerConfig, TeamWorkerConfig
 
 if TYPE_CHECKING:
     from collections.abc import AsyncIterator, Sequence
-    from contextlib import (
-        AbstractAsyncContextManager,
-    )
+    from contextlib import AbstractAsyncContextManager
     from types import TracebackType
 
     from psygnal.containers._evented_dict import DictEvents
@@ -58,10 +51,9 @@ logger = get_logger(__name__)
 
 
 TResult = TypeVar("TResult", default=Any)
-TPoolDeps = TypeVar("TPoolDeps", default=None)
 
 
-class AgentPool[TPoolDeps](BaseRegistry[NodeName, MessageEmitter[Any, Any]]):
+class AgentPool[TPoolDeps = None](BaseRegistry[NodeName, MessageEmitter[Any, Any]]):
     """Pool managing message processing nodes (agents and teams).
 
     Acts as a unified registry for all nodes, providing:
@@ -717,7 +709,6 @@ class AgentPool[TPoolDeps](BaseRegistry[NodeName, MessageEmitter[Any, Any]]):
                     case AgentWorkerConfig():
                         agent.register_worker(
                             worker,
-                            name=worker_config.name,
                             reset_history_on_run=worker_config.reset_history_on_run,
                             pass_message_history=worker_config.pass_message_history,
                             share_context=worker_config.share_context,
