@@ -280,7 +280,7 @@ class TeamRun[TDeps, TResult](BaseTeam[TDeps, TResult]):
 
                     return Usage(0, 0)
 
-                async def stream_output(self) -> AsyncGenerator[str, None]:  # type: ignore
+                async def stream_output(self) -> AsyncGenerator[str]:  # type: ignore
                     for idx, stream in enumerate(self.streams):
                         self.current_stream_idx = idx
                         async for chunk in stream.stream_output():
@@ -291,7 +291,7 @@ class TeamRun[TDeps, TResult](BaseTeam[TDeps, TResult]):
                 async def stream_text(
                     self,
                     delta: bool = False,
-                ) -> AsyncGenerator[str, None]:
+                ) -> AsyncGenerator[str]:
                     for idx, stream in enumerate(self.streams):
                         self.current_stream_idx = idx
                         async for chunk in stream.stream_text(delta=delta):
@@ -326,12 +326,12 @@ if __name__ == "__main__":
             agent1 = await pool.add_agent(
                 "analyzer",
                 system_prompt="You analyze text and find key points.",
-                model="openai:gpt-5-mini",
+                model="openai:gpt-5-nano",
             )
             agent2 = await pool.add_agent(
                 "summarizer",
                 system_prompt="You create concise summaries.",
-                model="openai:gpt-5-mini",
+                model="openai:gpt-5-nano",
             )
 
             # Create team and get monitored execution
