@@ -194,7 +194,7 @@ class MCPClient:
 
     def create_tool_callable(self, tool: MCPTool) -> Callable[..., Awaitable[str]]:
         """Create a properly typed callable from MCP tool schema."""
-        from py2openai.functionschema import FunctionSchema
+        from schemez.functionschema import FunctionSchema
 
         schema = mcp_tool_to_fn_schema(tool)
         fn_schema = FunctionSchema.from_dict(schema)
@@ -202,7 +202,16 @@ class MCPClient:
 
         async def tool_callable(**kwargs: Any) -> str:
             """Dynamically generated MCP tool wrapper."""
-            return await self.call_tool(tool.name, kwargs)
+            # Filter out None values for optional params to avoid MCP validation errors
+            # Only include parameters that are either required or have non-None values
+            schema_props = tool.inputSchema.get("properties", {})
+            required_props = set(tool.inputSchema.get("required", []))
+            filtered_kwargs = {
+                k: v
+                for k, v in kwargs.items()
+                if k in required_props or (k in schema_props and v is not None)
+            }
+            return await self.call_tool(tool.name, filtered_kwargs)
 
         # Set proper signature and docstring
         tool_callable.__signature__ = sig  # type: ignore
