@@ -3,13 +3,13 @@
 from __future__ import annotations
 
 from functools import cached_property
-import logging
 from typing import TYPE_CHECKING, Any, Self
 
 from pydantic import ConfigDict, Field, model_validator
 from schemez.schema import Schema
 
-from llmling_agent.models.agents import AgentConfig
+from llmling_agent import log
+from llmling_agent.models.agents import AgentConfig  # noqa: TC001
 from llmling_agent.resource_registry import ResourceRegistry
 from llmling_agent_config.converters import ConversionConfig
 from llmling_agent_config.mcp_server import (
@@ -43,10 +43,9 @@ if TYPE_CHECKING:
     from llmling_agent.prompts.manager import PromptManager
 
 
-logger = logging.getLogger(__name__)
+logger = log.get_logger(__name__)
 
 
-# TODO: python 3.13: set defaults here
 class AgentsManifest(Schema):
     """Complete agent configuration manifest defining all available agents.
 
@@ -488,6 +487,6 @@ class AgentsManifest(Schema):
 
 if __name__ == "__main__":
     model = {"type": "input"}
-    agent_cfg = AgentConfig(name="test_agent", model=model)  # type: ignore
-    manifest = AgentsManifest(agents=dict(test_agent=agent_cfg))
+    agent_cfg = dict(name="test_agent", model=model)  # type: ignore
+    manifest = AgentsManifest(agents=dict(test_agent=agent_cfg))  # type: ignore
     print(manifest.agents["test_agent"].model)
