@@ -11,6 +11,7 @@ import typer as t
 
 from llmling_agent.log import set_handler_level
 from llmling_agent_cli import resolve_agent_config
+from llmling_agent_cli.cli_types import LogLevel  # noqa: TC001
 
 
 if TYPE_CHECKING:
@@ -32,12 +33,11 @@ def chat_command(
     model: str | None = t.Option(None, "--model", "-m", help="Override agent's model"),
     stream: bool = t.Option(True, STREAM_CMD, help=STREAM_HELP),
     connections: list[str] = t.Option(None, "--forward-to", "-f", help=FORWARD_HELP),  # noqa: B008
-    log_level: str = t.Option(
-        "WARNING",
+    log_level: LogLevel = t.Option(  # noqa: B008
+        "warning",
         "--log-level",
         "-l",
-        help="Log level (DEBUG, INFO, WARNING, ERROR)",
-        case_sensitive=False,
+        help="Log level",
     ),
 ):
     """Start interactive chat session with an agent.
@@ -48,14 +48,13 @@ def chat_command(
     """
     from slashed import DefaultOutputWriter
 
-    from llmling_agent.delegation import AgentPool
+    from llmling_agent import AgentPool
     from llmling_agent_cli.chat_session.session import start_interactive_session
 
     level = getattr(logging, log_level.upper())
     logging.basicConfig(level=level)
 
     try:
-        # Resolve configuration
         try:
             config_path = resolve_agent_config(config)
         except ValueError as e:
@@ -63,23 +62,17 @@ def chat_command(
             raise t.BadParameter(msg) from e
 
         async def run_chat():
-            # Create pool with main agent and forwarding targets
-            async with AgentPool[None](
-                config_path,
-                connect_nodes=False,  # We'll handle connections manually
-            ) as pool:
-                # Get main agent
+            # Create pool with main agent, forwarding targets, and connections
+            async with AgentPool[None](config_path, connect_nodes=False) as pool:
                 agent: Agent[Any] = pool.get_agent(agent_name, session=session_id)
                 if model:
                     agent.set_model(model)
-
-                # Set up forwarding if requested
                 if connections:
                     for target in connections:
                         target_agent = pool.get_agent(target)
                         agent.connect_to(target_agent)
 
-                await start_interactive_session(agent, pool=pool, stream=stream)
+                await start_interactive_session(agent, stream=stream)
 
         show_logs = False
         output = DefaultOutputWriter() if show_logs else None
