@@ -2,21 +2,20 @@
 
 from __future__ import annotations
 
-from datetime import datetime  # noqa: TC003
-import logging
+from datetime import datetime
 
 from llmling.cli.constants import output_format_opt
-from llmling.cli.utils import format_output
+from llmling.cli.utils import OutputFormat, format_output
 import typer as t
 
-from llmling_agent import AgentsManifest
+from llmling_agent import AgentsManifest, log
 from llmling_agent.utils.now import get_now
 from llmling_agent.utils.parse_time import parse_time_period
 from llmling_agent_cli import resolve_agent_config
-from llmling_agent_cli.cli_types import GroupBy  # noqa: TC001
+from llmling_agent_cli.cli_types import GroupBy
 
 
-logger = logging.getLogger(__name__)
+logger = log.get_logger(__name__)
 
 help_text = "Conversation history management"
 history_cli = t.Typer(name="history", help=help_text, no_args_is_help=True)
@@ -59,7 +58,7 @@ def show_history(
     limit: int = t.Option(10, "--limit", "-n", help="Number of conversations"),
     compact: bool = t.Option(False, "--compact", help=COMPACT_HELP),
     tokens: bool = t.Option(False, "--tokens", "-t", help=TOKEN_HELP),
-    output_format: str = output_format_opt,
+    output_format: OutputFormat = output_format_opt,
 ):
     """Show conversation history with filtering options.
 
@@ -114,7 +113,7 @@ def show_stats(
         "1d", "--period", "-p", help="Time period (1h, 1d, 1w, 1m, 1y)"
     ),
     group_by: GroupBy = t.Option("agent", "--group-by", "-g", help="Group by"),  # noqa: B008
-    output_format: str = output_format_opt,
+    output_format: OutputFormat = output_format_opt,
 ):
     """Show usage statistics.
 
