@@ -2,19 +2,14 @@
 
 from __future__ import annotations
 
-from typing import TYPE_CHECKING
-
 from slashed import Command, CommandContext, CommandError  # noqa: TC002
 from slashed.completers import CallbackCompleter
 
+from llmling_agent.agent.context import AgentContext  # noqa: TC001
+from llmling_agent.messaging.context import NodeContext  # noqa: TC001
 from llmling_agent_commands.completers import get_available_agents
 
 
-if TYPE_CHECKING:
-    from llmling_agent.agent.context import AgentContext
-    from llmling_agent.messaging.context import NodeContext
-
-
 CREATE_AGENT_HELP = """\
 Create a new agent in the current session.
 
