@@ -2,18 +2,13 @@
 
 from __future__ import annotations
 
-from typing import TYPE_CHECKING
-
 from slashed import Command, CommandContext, CommandError  # noqa: TC002
 from slashed.completers import PathCompleter
 
+from llmling_agent.agent.context import AgentContext  # noqa: TC001
 from llmling_agent.log import get_logger
 
 
-if TYPE_CHECKING:
-    from llmling_agent.agent.context import AgentContext
-
-
 logger = get_logger(__name__)
 
 
@@ -56,7 +51,7 @@ async def read_command(
         return
 
     path = args[0]
-    convert_to_md = kwargs.get("convert_to_md", "").lower() in ("true", "1", "yes")
+    convert_to_md = kwargs.get("convert_to_md", "").lower() in {"true", "1", "yes"}
 
     try:
         agent = ctx.context.agent
