@@ -2,19 +2,14 @@
 
 from __future__ import annotations
 
-from typing import TYPE_CHECKING
-
 from slashed import Command, CommandContext, CommandError  # noqa: TC002
 from slashed.completers import CallbackCompleter
 
+from llmling_agent.agent.context import AgentContext  # noqa: TC001
 from llmling_agent.log import get_logger
 from llmling_agent_commands.completers import get_resource_names
 
 
-if TYPE_CHECKING:
-    from llmling_agent.agent.context import AgentContext
-
-
 logger = get_logger(__name__)
 
 LIST_RESOURCES_HELP = """\
